[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula A"}},"key":"1D434"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula B"}},"key":"1D435"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula C"}},"key":"1D436"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula D"}},"key":"1D437"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula E"}},"key":"1D438"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula F"}},"key":"1D439"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula G"}},"key":"1D43A"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula H"}},"key":"1D43B"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula I"}},"key":"1D43C"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula J"}},"key":"1D43D"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula K"}},"key":"1D43E"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula L"}},"key":"1D43F"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula M"}},"key":"1D440"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula N"}},"key":"1D441"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula O"}},"key":"1D442"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula P"}},"key":"1D443"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Q"}},"key":"1D444"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula R"}},"key":"1D445"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula S"}},"key":"1D446"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula T"}},"key":"1D447"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula U"}},"key":"1D448"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula V"}},"key":"1D449"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula W"}},"key":"1D44A"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula X"}},"key":"1D44B"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Y"}},"key":"1D44C"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Z"}},"key":"1D44D"},{"category":"Ll","mappings":{"default":{"default":"cursiva a"}},"key":"1D44E"},{"category":"Ll","mappings":{"default":{"default":"cursiva b"}},"key":"1D44F"},{"category":"Ll","mappings":{"default":{"default":"cursiva c"}},"key":"1D450"},{"category":"Ll","mappings":{"default":{"default":"cursiva d"}},"key":"1D451"},{"category":"Ll","mappings":{"default":{"default":"cursiva e"}},"key":"1D452"},{"category":"Ll","mappings":{"default":{"default":"cursiva f"}},"key":"1D453"},{"category":"Ll","mappings":{"default":{"default":"cursiva g"}},"key":"1D454"},{"key":"210E","mappings":{"default":{"default":"constante de Planck"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"cursiva i"}},"key":"1D456"},{"category":"Ll","mappings":{"default":{"default":"cursiva j"}},"key":"1D457"},{"category":"Ll","mappings":{"default":{"default":"cursiva k"}},"key":"1D458"},{"category":"Ll","mappings":{"default":{"default":"cursiva l"}},"key":"1D459"},{"category":"Ll","mappings":{"default":{"default":"cursiva m"}},"key":"1D45A"},{"category":"Ll","mappings":{"default":{"default":"cursiva n"}},"key":"1D45B"},{"category":"Ll","mappings":{"default":{"default":"cursiva o"}},"key":"1D45C"},{"category":"Ll","mappings":{"default":{"default":"cursiva p"}},"key":"1D45D"},{"category":"Ll","mappings":{"default":{"default":"cursiva q"}},"key":"1D45E"},{"category":"Ll","mappings":{"default":{"default":"cursiva r"}},"key":"1D45F"},{"category":"Ll","mappings":{"default":{"default":"cursiva s"}},"key":"1D460"},{"category":"Ll","mappings":{"default":{"default":"cursiva t"}},"key":"1D461"},{"category":"Ll","mappings":{"default":{"default":"cursiva u"}},"key":"1D462"},{"category":"Ll","mappings":{"default":{"default":"cursiva v"}},"key":"1D463"},{"category":"Ll","mappings":{"default":{"default":"cursiva w"}},"key":"1D464"},{"category":"Ll","mappings":{"default":{"default":"cursiva x"}},"key":"1D465"},{"category":"Ll","mappings":{"default":{"default":"cursiva y"}},"key":"1D466"},{"category":"Ll","mappings":{"default":{"default":"cursiva z"}},"key":"1D467"}]
